@@ -122,7 +122,7 @@ Processes the response content of stream search.
 
 =item *
 
-I<$for_each_callback>: The callback subroutine which is invoked to process each
+I<for_each_callback>: The callback subroutine which is invoked to process each
 parsed L<Google::Ads::GoogleAds::VX::Services::GoogleAdsService::GoogleAdsRow>.
 
 =back
